;;; pk-unpk.el --- Commands to instrument Scheme code

;; Copyright (C) 2002, 2007 Thien-Thi Nguyen
;;
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 3, or (at your option)
;; any later version.
;;
;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with this software; see the file COPYING.  If not, write to
;; the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
;; Boston, MA 02110-1301, USA.

;;; Author: Thien-Thi Nguyen <ttn@gnu.org>

;;; Commentary:

;; `M-x pk' asks you for a string to insert as `pk' arguments.
;; For example:
;;
;;              (let ((answer (compute-answer))) ...)
;;                            ^
;;                            point is here
;;
;; Try `M-x pk' then type
;;
;;              'answer 'is
;;
;; The code then looks like:
;;
;;              (let ((answer (pk 'answer 'is (compute-answer)))) ...)
;;
;; `M-x unpk' searches backwards and upwards for a `pk' form and removes
;; it, or signals error if one cannot be found.

;;; Code:

(defun pk (tag)
  (interactive "sTag (`pk' args): ")
  (skip-chars-forward " \t\n")
  (save-excursion
    (insert "(pk " tag " ")
    (forward-sexp)
    (insert ")")))

(defun unpk ()
  (interactive)
  (skip-chars-forward " \t\n")
  (while (not (looking-at "(pk"))
    (when (zerop (current-column))
      (error "could not find surrounding pk"))
    (backward-up-list 1))
  (let ((p (point)))
    (forward-sexp 1)
    (delete-char -1)
    (forward-sexp -1)
    (delete-region p (point))))

(provide 'pk-unpk)

;;; pk-unpk.el ends here
